import { CircleNode, CircleNodeModel, GraphModel } from '@logicflow/core';
import { storeToRefs } from 'pinia';
import { useThemeConfig } from '@/stores/themeConfig';
const storesThemeConfig = useThemeConfig();
const { themeConfig } = storeToRefs(storesThemeConfig);
import { nodeStyleHandle } from '../tool'
class StartModel extends CircleNodeModel {
  static extendKey = 'StartModel';
  constructor(data: any, graphModel: GraphModel) {
    if (!data.text) {
      data.text = ''
    }
    if (data.text && typeof data.text === 'string') {
      data.text = {
        value: data.text,
        x: data.x,
        y: data.y - 40
      }
    }
    super(data, graphModel)
  }

  setAttributes(): void {
    this.r = 20
  }

  // getConnectedTargetRules(): ConnectRule[] {
  //   const rules = super.getConnectedTargetRules()
  //   const notAsTarget = {
  //     message: '起始节点不能作为边的终点',
  //     validate: () => false
  //   }
  //   rules.push(notAsTarget)
  //   return rules
  // }

  getNodeStyle(): {
    [x: string]: any;
    r?: number;
    fill?: string;
    width?: number;
    height?: number;
    stroke?: string;
    strokeWidth?: number;
  } {
    const style = super.getNodeStyle()
    // 设置样式
    if (themeConfig.value.isIsDark) {
      style.fill = "#191919";
      style.stroke = "#fff"
    } else {
      style.fill = "#fff";
      style.stroke = "#3C50E0";
    }
    return nodeStyleHandle(this, style)
  }
}

class StartView extends CircleNode {
  static extendKey = 'StartNode';
}

const Start = {
  type: 'hotline:start',
  view: StartView,
  model: StartModel
}

export { StartModel, StartView }
export default Start
